@@ -4,7 +4,7 @@
 #  | .__/  \___| \___||_|\_\
 #  |_| like print, but easy.
 
-__version__ = "25.0.8"
+__version__ = "25.0.9"
 
 """
 See https://github.com/salabim/peek for details
@@ -447,13 +447,13 @@ class _Peek:
                 parent_function = ""
             else:
                 parent_function = f" in {parent_function}()"
-            if 0 <= line_number - 1 < len(code) - 1:
+            try:
                 this_line = code[line_number - 1].strip()
-            else:
+            except IndexError:
                 this_line = ""
-            if 0 <= line_number - 2 < len(code) - 2:
+            try:
                 this_line_prev = code[line_number - 2].strip()
-            else:
+            except IndexError:
                 this_line_prev = ""
         if this_line.startswith("@") or this_line_prev.startswith("@"):
             if as_str:
@@ -501,8 +501,10 @@ class _Peek:
             this._line_number_with_filename_and_parent = ""
         else:
             line_number = call_node.lineno
-            this_line = code[line_number - 1].strip()
-
+            try:
+                this_line = code[line_number - 1].strip()
+            except IndexError:
+                this_line=""
             this._line_number_with_filename_and_parent = f"#{line_number}{filename_name}{parent_function}"
 
         if this_line.startswith("with ") or this_line.startswith("with\t"):
